@@ -1,22 +1,21 @@
 #!/bin/sh
 
-if [ "x${PD}" = "x" ]
-then
- PD=pd
-fi
 
-if [ "x${PDARGS}" = "x" ]
-then
- PDARGS="-noprefs -nosound -nrt"
-fi
+: ${PD:=pd}
+: ${PDARGS:=-noprefs -nosound -nrt}
 
+: ${libdir:=..}
+: ${absdir:=../abs}
+
+: ${IEMMATRIX:=-lib "${libdir}/iemmatrix" -path "${absdir}"}
 
 RUNTESTS_TXT=runtests.txt
 RUNTESTS_LOG=runtests.log
+XITCODE=0
 
-ls -1 */*.pd | sed 's/\.pd/;/' > $RUNTESTS_TXT
-
-IEMMATRIX="-lib ../iemmatrix -path ../abs/"
+for f in */*.pd; do
+  test -e "${f}" && echo "${f%.pd};"
+done | LC_ALL=C sort > $RUNTESTS_TXT
 
 run_nogui() {
  ${PD} ${PDARGS} $IEMMATRIX -nogui runtests_nogui.pd > ${RUNTESTS_LOG} 2>&1
@@ -30,6 +29,9 @@ run_nogui() {
    echo -n "${ft} "
  done
  echo
+ if [ "x${FAILEDTESTS}" != "x" ]; then
+   XITCODE=1
+ fi
 }
 
 run_withgui() {
@@ -43,4 +45,4 @@ else
  run_nogui
 fi
 
-
+exit ${XITCODE}
